pub struct HomographicAlignment {
pub matrix: [[f32; 3]; 3],
}Expand description
3×3 row-major homography matrix that warps the floating image into the target’s coordinate system.
Fields
matrix: [[f32; 3]; 3]Trait Implementations
Sourceimpl Clone for HomographicAlignment
impl Clone for HomographicAlignment
Sourcefn clone(&self) -> HomographicAlignment
fn clone(&self) -> HomographicAlignment
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for HomographicAlignment
impl Debug for HomographicAlignment
Sourceimpl PartialEq for HomographicAlignment
impl PartialEq for HomographicAlignment
Sourcefn eq(&self, other: &HomographicAlignment) -> bool
fn eq(&self, other: &HomographicAlignment) -> bool
Tests for
self and other values to be equal, and is used by ==.impl Copy for HomographicAlignment
impl StructuralPartialEq for HomographicAlignment