pub struct TranslationalAlignment {
pub tx: f64,
pub ty: f64,
}Expand description
2D translation in source-image coordinates needed to align the floating image to the target.
Fields
tx: f64ty: f64Trait Implementations
Sourceimpl Clone for TranslationalAlignment
impl Clone for TranslationalAlignment
Sourcefn clone(&self) -> TranslationalAlignment
fn clone(&self) -> TranslationalAlignment
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for TranslationalAlignment
impl Debug for TranslationalAlignment
Sourceimpl PartialEq for TranslationalAlignment
impl PartialEq for TranslationalAlignment
Sourcefn eq(&self, other: &TranslationalAlignment) -> bool
fn eq(&self, other: &TranslationalAlignment) -> bool
Tests for
self and other values to be equal, and is used by ==.impl Copy for TranslationalAlignment
impl StructuralPartialEq for TranslationalAlignment