pub struct TextRectanglesRequest { /* private fields */ }Expand description
Builder for VNDetectTextRectanglesRequest.
Implementations
Sourceimpl TextRectanglesRequest
impl TextRectanglesRequest
pub const fn new() -> Self
pub const fn with_image_based_request( self, image_based: ImageBasedRequest, ) -> Self
pub const fn with_report_character_boxes( self, report_character_boxes: bool, ) -> Self
pub const fn image_based_request(&self) -> &ImageBasedRequest
pub const fn report_character_boxes(&self) -> bool
Sourcepub fn perform(
&self,
path: impl AsRef<Path>,
) -> Result<Vec<TextObservation>, VisionError>
pub fn perform( &self, path: impl AsRef<Path>, ) -> Result<Vec<TextObservation>, VisionError>
Perform the request against path and return dedicated VNTextObservation
wrappers.
Errors
Returns VisionError if the image cannot be loaded or Vision rejects
the request.